### <img src="https://cdn2.hubspot.net/hubfs/100006/images/super_square_logo_3a.png" title="SeleniumBase" height="32"> SeleniumBase browser extension storage

**The List:**
* disable_csp.zip => Disable Chrome's Content-Security-Policy
